@@ -15,7 +15,7 @@
 # You should have received a copy of the GNU General Public License along
 # with PFT.  If not, see <http://www.gnu.org/licenses/>.
 #
-package PFT::Content::File v1.1.2;
+package PFT::Content::File v1.2.0;
 
 =encoding utf8
 
@@ -57,6 +57,11 @@ use overload
         my($name, $path) = @{$self}{'name', 'path'};
         ref($self) . "({name => \"$name\", path => \"$path\"})"
     },
+   'cmp' => sub {
+        my($self, $oth, $swap) = @_;
+        my $out = $self->{path} cmp $oth->{path};
+        $swap ? -$out : $out;
+    },
 ;
 
 sub new {
