@@ -15,7 +15,7 @@
 # You should have received a copy of the GNU General Public License along
 # with PFT.  If not, see <http://www.gnu.org/licenses/>.
 #
-package PFT::Date v1.1.2;
+package PFT::Date v1.2.0;
 
 =pod
 
@@ -113,8 +113,8 @@ sub from_spec {
     if (local $_ = $params{m}) {
         if (/^\d{1,2}$/) {
             $params{m} = int($_)
-        } elsif (m/^(j(?:a|u[nl])|[fsond]|ma[ry]|a[pu]).*/) {
-            $params{m} = $MONTHS{$1}
+        } elsif (m/^(j(?:a|u[nl])|[fsond]|ma[ry]|a[pu]).*/i) {
+            $params{m} = $MONTHS{lc $1}
         } else {
             croak "Invalid month: $_";
         }
