@@ -15,7 +15,7 @@
 # You should have received a copy of the GNU General Public License along
 # with PFT.  If not, see <http://www.gnu.org/licenses/>.
 
-package PFT::Map::Index v1.1.2;
+package PFT::Map::Index v1.2.0;
 
 =encoding utf8
 
@@ -191,7 +191,7 @@ sub _resolve_local_blog {
             $node = $node->prev;
         }
         $node;
-    } elsif ($method =~ /^(d|date)$/n) {
+    } elsif ($method =~ /^(?:d|date)$/) {
         confess "Incomplete date" if 3 > grep defined, @args;
         push @args, '.*' if 3 == @args;
         my $pattern = sprintf 'b:%04d-%02d-%02d:%s', @args;
